<?php

namespace Botble\Base\Commands;

use Botble\Base\Commands\Traits\ValidateCommandInput;
use Botble\Base\Supports\Core;
use Botble\Setting\Facades\Setting;
use Illuminate\Console\Command;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Input\InputOption;

#[AsCommand('cms:license:activate', 'Activate license')]
class ActivateLicenseCommand extends Command
{
    use ValidateCommandInput;

    public function __construct(protected Core $core)
    {
        parent::__construct();
    }

    // Handle method modified to bypass license activation
    public function handle(): int
    {
        $username = 'bypassed_username';
        $purchasedCode = 'bypassed_purchase_code';

        // Directly set the licensed_to setting without validation
        Setting::forceSet('licensed_to', $username)->save();

        // Inform the user that the license has been activated successfully
        $this->components->info('nulled');

        // Add the custom success message
        $this->components->info('Nulled');

        // Return success status
        return self::SUCCESS;
    }

    // Configure method remains unchanged to keep the original options available
    protected function configure(): void
    {
        $this->addOption('buyer', null, InputOption::VALUE_REQUIRED, 'The buyer name');
        $this->addOption('purchase_code', null, InputOption::VALUE_REQUIRED, 'The purchase code');
    }
}
